==> ath1121501_1.8.2.tar.gz: ath1121501/man/ath1121501GO.Rd <==
\name{ath1121501GO}
\alias{ath1121501GO}
\title{Map between Manufacturer IDs and Gene Ontology (GO)}
\description{
  ath1121501GO is an R environment that provides mappings between
  manufacturer ids and GO ids.
}
\details{
  Each manufacturer id is mapped to a named vector of GO ids. The name
  associated with each GO id corresponds to the evidence code for that
  GO id. Evidence codes currently in use include:
  
  IMP: inferred from mutant phenotype  

  IGI: inferred from genetic interaction

  IPI: inferred from physical interaction  

  ISS: inferred from sequence similarity 

  IDA: inferred from direct assay  

  IEP: inferred from expression pattern  

  IEA: inferred from electronic annotation  

  TAS: traceable author statement  

  NAS: non-traceable author statement  

  ND: no biological data available  

  IC: inferred by curator
  
  Mappings between probe ids and GO information were obtained through
  their mappings to Entrez Gene ids. NAs are assigned to probe identifiers
  that can not be mapped to any Gene Ontology information. Mappings
  between Gene Ontology ids an Gene Ontology terms and other information
  are available in a separate data package named GO.
  
  Mappings were based on data provided by:
  
  Tair: \url{ftp://ftp.arabidopsis.org/home/tair/Genes/gene_aliases.20041105}
Tair: \url{ftp://ftp.arabidopsis.org/home/tair/Genes/TAIR_sequenced_genes}
Tair: \url{ftp://ftp.arabidopsis.org/home/tair/Genes/Gene_Anatomy/ATH_Anatomy.20040209.txt}
Built: N/A

  Tair: \url{ftp://ftp.arabidopsis.org/home/tair/Ontologies/Gene_Ontology/ATH_GO_GOSLIM.20050514.txt}
Built: N/A
  
  Package built Tue May 17 18:45:34 2005
}

\examples{
    # Convert to a list
    xx <- as.list(ath1121501GO)
    # Remove all the NAs
    xx <- xx[!is.na(xx)]
    if(length(xx) > 0){
            # Try the firest one
            got <- xx[[1]]           
            got[[1]][["GOID"]]
            got[[1]][["Ontology"]]
            got[[1]][["Evidence"]]

    }
}
\keyword{datasets}

==> ath1121501_1.10.0.tar.gz: ath1121501/man/ath1121501GO.Rd <==
\name{ath1121501GO}
\alias{ath1121501GO}
\title{Map between Manufacturer IDs and Gene Ontology (GO)}
\description{
  ath1121501GO is an R environment that provides mappings between
  manufacturer ids and GO ids.
}
\details{
  Each manufacturer id is mapped to a named vector of GO ids. The name
  associated with each GO id corresponds to the evidence code for that
  GO id. Evidence codes currently in use include:
  
  IMP: inferred from mutant phenotype  

  IGI: inferred from genetic interaction

  IPI: inferred from physical interaction  

  ISS: inferred from sequence similarity 

  IDA: inferred from direct assay  

  IEP: inferred from expression pattern  

  IEA: inferred from electronic annotation  

  TAS: traceable author statement  

  NAS: non-traceable author statement  

  ND: no biological data available  

  IC: inferred by curator
  
  Mappings between probe ids and GO information were obtained through
  their mappings to Entrez Gene ids. NAs are assigned to probe identifiers
  that can not be mapped to any Gene Ontology information. Mappings
  between Gene Ontology ids an Gene Ontology terms and other information
  are available in a separate data package named GO.
  
  Mappings were based on data provided by:
  
  Tair: \url{http://gopher5/compbio/annotationSourceData/ftp.arabidopsis.org/home/tair/Genes/gene_aliases.20041105}
Tair: \url{http://gopher5/compbio/annotationSourceData/ftp.arabidopsis.org/home/tair/Genes/TAIR_sequenced_genes}
Tair: \url{http://gopher5/compbio/annotationSourceData/ftp.arabidopsis.org/home/tair/Ontologies/TAIR_Ontology/ATH_anatomy.20050119.txt}
Built: N/A

  Tair: \url{http://gopher5/compbio/annotationSourceData/ftp.arabidopsis.org/home/tair/Ontologies/Gene_Ontology/ATH_GO_GOSLIM.20050924.txt}
Built: N/A
  
  Package built Tue Oct  4 19:05:27 2005
}

\examples{
    # Convert to a list
    xx <- as.list(ath1121501GO)
    # Remove all the NAs
    xx <- xx[!is.na(xx)]
    if(length(xx) > 0){
            # Try the firest one
            got <- xx[[1]]           
            got[[1]][["GOID"]]
            got[[1]][["Ontology"]]
            got[[1]][["Evidence"]]

    }
}
\keyword{datasets}
